aboutsummaryrefslogtreecommitdiff
path: root/src/libjin/Graphics/je_shapes.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/libjin/Graphics/je_shapes.h')
-rw-r--r--src/libjin/Graphics/je_shapes.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/libjin/Graphics/je_shapes.h b/src/libjin/Graphics/je_shapes.h
index bb2da25..ea010be 100644
--- a/src/libjin/Graphics/je_shapes.h
+++ b/src/libjin/Graphics/je_shapes.h
@@ -7,9 +7,9 @@
#include "je_canvas.h"
#include "je_texture.h"
-namespace jin
+namespace JinEngine
{
- namespace graphics
+ namespace Graphics
{
typedef enum {
@@ -30,8 +30,8 @@ namespace jin
extern void points(int n, GLshort* p, GLubyte* c);
extern void polygon(RenderMode mode, float* p, int count);
- } // namespace graphics
-} // namespace jin
+ } // namespace Graphics
+} // namespace JinEngine
#endif // LIBJIN_MODULES_RENDER
#endif // __JE_GEOMETRY_H \ No newline at end of file